@@ -2,11 +2,6 @@
 
 ;; Copyright © 2020-2025 Jethro Kuan <jethrokuan95@gmail.com>
 
-;; Author: Jethro Kuan <jethrokuan95@gmail.com>
-;; URL: https://github.com/org-roam/org-roam
-;; Keywords: org-mode, roam, convenience
-;; Package-Requires: ((emacs "26.1") (dash "2.13") (org "9.6") (emacsql "4.1.0") (magit-section "3.0.0"))
-
 ;; This file is NOT part of GNU Emacs.
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -184,7 +179,9 @@ information in a section-like manner (see
 `org-roam-mode-sections'), with which the user can
 interact with."
   :group 'org-roam
-  (face-remap-add-relative 'header-line 'org-roam-header-line))
+  (face-remap-add-relative 'header-line 'org-roam-header-line)
+  ;; https://github.com/meedstrom/org-node/issues/149
+  (setq-local font-lock-defaults nil))
 
 ;;; Buffers
 (defvar org-roam-buffer-current-node nil
@@ -213,11 +210,11 @@ which visits the thing at point."
 (defun org-roam-buffer-file-at-point (&optional assert)
   "Return the file at point in the current `org-roam-mode' based buffer.
 If ASSERT, throw an error."
-  (if-let ((file (magit-section-case
-                   (org-roam-node-section (org-roam-node-file (oref it node)))
-                   (org-roam-grep-section (oref it file))
-                   (org-roam-preview-section (oref it file))
-                   (t (cl-assert (derived-mode-p 'org-roam-mode))))))
+  (if-let* ((file (magit-section-case
+                    (org-roam-node-section (org-roam-node-file (oref it node)))
+                    (org-roam-grep-section (oref it file))
+                    (org-roam-preview-section (oref it file))
+                    (t (cl-assert (derived-mode-p 'org-roam-mode))))))
       file
     (when assert
       (user-error "No file at point"))))
@@ -329,7 +326,7 @@ Valid states are `visible', `exists' and `none'."
 (defun org-roam-buffer-persistent-redisplay ()
   "Recompute contents of the persistent `org-roam-buffer'.
 Has no effect when there's no `org-roam-node-at-point'."
-  (when-let ((node (org-roam-node-at-point)))
+  (when-let* ((node (org-roam-node-at-point)))
     (unless (equal node org-roam-buffer-current-node)
       (setq org-roam-buffer-current-node node
             org-roam-buffer-current-directory org-roam-directory)
@@ -392,7 +389,7 @@ the same time:
    other node) at POINT. Acts a child section of the previous
    one."
   (magit-insert-section section (org-roam-node-section)
-    (let ((outline (if-let ((outline (plist-get properties :outline)))
+    (let ((outline (if-let* ((outline (plist-get properties :outline)))
                        (mapconcat #'org-link-display-format outline " > ")
                      "Top")))
       (insert (concat (propertize (org-roam-node-title source-node)
@@ -524,7 +521,7 @@ When SHOW-BACKLINK-P is not null, only show backlinks for which
 this predicate is not nil.
 
 SECTION-HEADING is the string used as a heading for the backlink section."
-  (when-let ((backlinks (seq-sort #'org-roam-backlinks-sort (org-roam-backlinks-get node :unique unique))))
+  (when-let* ((backlinks (seq-sort #'org-roam-backlinks-sort (org-roam-backlinks-get node :unique unique))))
     (magit-insert-section (org-roam-backlinks)
       (magit-insert-heading section-heading)
       (dolist (backlink backlinks)
@@ -582,8 +579,8 @@ Sorts by title."
 
 (defun org-roam-reflinks-section (node)
   "The reflinks section for NODE."
-  (when-let ((refs (org-roam-node-refs node))
-             (reflinks (seq-sort #'org-roam-reflinks-sort (org-roam-reflinks-get node))))
+  (when-let* ((refs (org-roam-node-refs node))
+              (reflinks (seq-sort #'org-roam-reflinks-sort (org-roam-reflinks-get node))))
     (magit-insert-section (org-roam-reflinks)
       (magit-insert-heading "Reflinks:")
       (dolist (reflink reflinks)
