@@ -5,9 +5,9 @@
 ;; Author: Jethro Kuan <jethrokuan95@gmail.com>
 ;; URL: https://github.com/org-roam/org-roam
 ;; Keywords: org-mode, roam, convenience
-;; Package-Version: 20250927.2243
-;; Package-Revision: 41f9a10be587
-;; Package-Requires: ((emacs "26.1") (dash "2.13") (org "9.6") (emacsql "4.1.0") (magit-section "3.0.0"))
+;; Package-Version: 20251112.1434
+;; Package-Revision: 6abb3bdc5a44
+;; Package-Requires: ((emacs "26.1") (compat "30.1") (dash "2.13") (org "9.6") (emacsql "4.1.0") (magit-section "3.0.0"))
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -78,6 +78,8 @@
 (require 'seq)
 (require 'cl-lib)
 
+(require 'compat)
+
 (require 'magit-section)
 
 (require 'emacsql)
@@ -142,7 +144,7 @@ responsibility to ensure that."
   :group 'org-roam)
 
 (defcustom org-roam-file-exclude-regexp (list org-attach-id-dir)
-  "Files matching this regular expression or list of regular expressions are excluded from the Org-roam."
+  "Files matching this regexp or list of regexps are excluded from Org-roam."
   :type '(choice
           (repeat
            (string :tag "Regular expression matching files to ignore"))
